@@ -3,6 +3,7 @@
 
 # Copyright (C) 2008 Pâris Quentin
 # Copyright (C) 2009 Łukasz Wojniłowicz
+# Copyright (C) 2007-2010 PlayOnLinux Team
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -265,7 +266,7 @@ class Ok_frame(wx.Frame): #fenêtre principale
 		octetsLoadedN = round(octetsLoadedB, 1)
 		tailleFichierN = round(tailleFichierB, 1)
 		
-		Variables.estimation_txt = str(octetsLoadedN) + " "+_("of")+" " + str(tailleFichierN) + " mo "+_("downloaded")
+		Variables.estimation_txt = str(octetsLoadedN) + " "+_("of")+" " + str(tailleFichierN) + _("MiB downloaded")
 		
 		self.txtEstimation.SetLabel(Variables.estimation_txt)
 		self.txtEstimation.SetFont(self.fontText)
@@ -555,11 +556,11 @@ class Ok_frame(wx.Frame): #fenêtre principale
 
 							if(self.fichier[1] == "make_shortcut\n"):
 								self.DrawHeader()
-								self.texte = wx.StaticText(self.panel, -1, _("Create a shortcut :"),pos=(20,80))
+								self.texte = wx.StaticText(self.panel, -1, _("Create a shortcut: "),pos=(20,80))
 								self.titre_header = wx.StaticText(self.header, -1, _("PlayOnLinux Wizard"),pos=(5,5), size=(340,356))
 								self.texte.SetFont(self.fontText)
 								self.titre_header.SetFont(self.fontTitre)
-								self.titre = wx.StaticText(self.header, -1, _("Do you want a shortcut for ")+self.fichier[2].replace("\n","")+" ?",pos=(20,30), size=(340,356))
+								self.titre = wx.StaticText(self.header, -1, _("Would you like a shortcut for: ")+self.fichier[2].replace("\n","")+" ?",pos=(20,30), size=(340,356))
 								self.desktop = wx.CheckBox(self.panel, -1, _("On your desktop"),pos=(25,105))
 								self.menu = wx.CheckBox(self.panel, -1, _("In your menu"),pos=(25,125))
 
