@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+# Copyright (C) 2007-2010 PlayOnLinux Team
 # Copyright (C) 2008 Pâris Quentin
 # Copyright (C) 2009 Łukasz Wojniłowicz
 
@@ -41,8 +42,29 @@ class MainWindow(wx.Frame):
 		#self.panel_update.SetBackgroundColour((255,255,225))
 
 		self.fontText = wx.Font(10, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD,False, "", wx.FONTENCODING_DEFAULT)
-		self.image_logo = wx.StaticBitmap(self.panel_update, -1, wx.ArtProvider.GetBitmap("gtk-refresh", wx.ART_MENU), pos=(15,0))
-		self.texte_update = wx.StaticText(self.panel_update, -1, _("An updated version of PlayOnLinux is available.")+" ("+sys.argv[1]+")",pos=(35,0))
+		#argv[1] = 1 nvversion -- argv[2] = version
+		#argv[1] = 2 no net
+		#argv[1] = 3 version de dev
+		#argv[1] = 4 unofficial website used
+		if(int(sys.argv[1]) == 1):
+			self.image_logo = wx.StaticBitmap(self.panel_update, -1, wx.ArtProvider.GetBitmap("gtk-refresh", wx.ART_MENU), pos=(15,0))
+			self.texte_update = wx.StaticText(self.panel_update, -1, _("An updated version of PlayOnLinux is available.")+" ("+sys.argv[2]+")",pos=(35,0))
+		elif(int(sys.argv[1]) == 2):
+			self.image_logo = wx.StaticBitmap(self.panel_update, -1, wx.ArtProvider.GetBitmap("gtk-dialog-warning", wx.ART_MENU), pos=(15,0))
+			self.texte_update = wx.StaticText(self.panel_update, -1, _("You do not seem to be connected to the Internet."),pos=(35,0))
+			self.texte_update.SetForegroundColour("red")
+		elif(int(sys.argv[1]) == 3):
+			self.image_logo = wx.StaticBitmap(self.panel_update, -1, wx.ArtProvider.GetBitmap("gtk-dialog-warning", wx.ART_MENU), pos=(15,0))
+			self.texte_update = wx.StaticText(self.panel_update, -1, _("Your are using a development version, be careful."),pos=(35,0))
+			self.texte_update.SetForegroundColour("orange")
+		elif(int(sys.argv[1]) == 4):
+			self.image_logo = wx.StaticBitmap(self.panel_update, -1, wx.ArtProvider.GetBitmap("gtk-dialog-warning", wx.ART_MENU), pos=(15,0))
+			self.texte_update = wx.StaticText(self.panel_update, -1, _("You seem to be using the Offline PlayOnLinux plugin."),pos=(35,0))
+			self.texte_update.SetForegroundColour("green")
+		else:
+			self.image_logo = wx.StaticBitmap(self.panel_update, -1, wx.ArtProvider.GetBitmap("gtk-dialog-error", wx.ART_MENU), pos=(15,0))
+			self.texte_update = wx.StaticText(self.panel_update, -1, _("Internal error when starting GUI. Please file a bug report ASAP!"),pos=(35,0))
+			
 		self.texte_update.SetFont(self.fontText)
 		self.list_game = wx.TreeCtrl(self.panel_games, 105, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT)
 
@@ -74,7 +96,7 @@ class MainWindow(wx.Frame):
     self.expertmenu = wx.Menu()
 
 
-    self.winever_item = wx.MenuItem(self.expertmenu, 107, _("Manage wine versions"))
+    self.winever_item = wx.MenuItem(self.expertmenu, 107, _("Manage Wine versions"))
     self.winever_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/menu/wine.png"))
     self.expertmenu.AppendItem(self.winever_item)
 
@@ -82,7 +104,7 @@ class MainWindow(wx.Frame):
     #self.wineserv_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/menu/wineserver.png"))
     #self.expertmenu.AppendItem(self.wineserv_item)
 
-    self.run_item = wx.MenuItem(self.expertmenu, 108, _("Run a non-official script"))
+    self.run_item = wx.MenuItem(self.expertmenu, 108, _("Run a local script"))
     self.run_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/menu/run.png"))
     self.expertmenu.AppendItem(self.run_item)
 
@@ -144,7 +166,7 @@ class MainWindow(wx.Frame):
     if(self.j > 0):
 	self.pluginsmenu.AppendSeparator()
 
-    self.option_item_p = wx.MenuItem(self.expertmenu, 214, _("Plugins manager"))
+    self.option_item_p = wx.MenuItem(self.expertmenu, 214, _("Plugin manager"))
     self.option_item_p.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/package-x-generic.png"))
     self.pluginsmenu.AppendItem(self.option_item_p)
  
@@ -220,7 +242,7 @@ class MainWindow(wx.Frame):
   def RMBInGameList(self, event):
 	self.GameListPopUpMenu = wx.Menu()
 
-	self.ConfigureWine = wx.MenuItem(self.GameListPopUpMenu, 230, _("Configure wine"))
+	self.ConfigureWine = wx.MenuItem(self.GameListPopUpMenu, 230, _("Configure Wine"))
 	self.ConfigureWine.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/menu/run.png"))
 	self.GameListPopUpMenu.AppendItem(self.ConfigureWine)
 
@@ -228,7 +250,7 @@ class MainWindow(wx.Frame):
 	self.RegistryEditor.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/menu/regedit.png"))
 	self.GameListPopUpMenu.AppendItem(self.RegistryEditor)
 
-	self.GotoAppDir = wx.MenuItem(self.GameListPopUpMenu, 232, _("Go to the application directory"))
+	self.GotoAppDir = wx.MenuItem(self.GameListPopUpMenu, 232, _("Open the application's directory"))
 	self.GotoAppDir.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/user-desktop.png"))
 	self.GameListPopUpMenu.AppendItem(self.GotoAppDir)
 
@@ -250,7 +272,7 @@ class MainWindow(wx.Frame):
 	webbrowser.open("http://www.playonlinux.com/donate.html");
 
   def RWineConfigurator(self, event):
-        self.RConfigure(_("Configure wine"), "nothing")
+        self.RConfigure(_("Configure Wine"), "nothing")
 
   def RKill(self, event):
         self.RConfigure(_("KillApp"), "nothing")
@@ -421,14 +443,16 @@ class MainWindow(wx.Frame):
     self.aboutBox.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
     self.aboutBox.SetName("PlayOnLinux")
     self.aboutBox.SetVersion(Variables.version)
-    self.aboutBox.SetDescription(_("Run your Windows programs on Linux !"))
-    self.aboutBox.SetCopyright(_("(C) PlayOnLinux team 2008\nUnder GPL licence version 3"))
-    self.aboutBox.AddDeveloper("Developer and Website : Tinou (Pâris Quentin)")	 
-    self.aboutBox.AddDeveloper("Scriptors : MulX (Petit Aymeric), GNU_Raziel, NSLW")
-    self.aboutBox.AddDeveloper("Packager : MulX (Petit Aymeric)")
-    self.aboutBox.AddDeveloper("Script Creator : Zoloom (Cassarin-Grand Arthur)")
-    self.aboutBox.AddDeveloper("Helped for the program : kiplantt, NSLW")
-    self.aboutBox.AddArtist("Icons are provided by Tango Desktop Project")
+    self.aboutBox.SetDescription(_("Run your Windows programs on Linux!"))
+    self.aboutBox.SetCopyright("(C) PlayOnLinux team 2007-2010\n"+_("Under GPL licence version 3."))
+    self.aboutBox.AddDeveloper(_("Developer and Website: ")+"Tinou (Pâris Quentin), MulX (Petit Aymeric)")	 
+    self.aboutBox.AddDeveloper(_("Scriptors: ")+"GNU_Raziel")
+    self.aboutBox.AddDeveloper(_("Packager: ")+"MulX (Petit Aymeric)")
+    #self.aboutBox.AddDeveloper(_("Script Creator: ")+"Zoloom (Cassarin-Grand Arthur)")
+    self.aboutBox.AddDeveloper(_("The following people contributed to this program: ")+"kiplantt, NSLW, Salvatos, Minchul")
+    self.aboutBox.AddTranslator(_("Translation made on Launchpad:"))
+    self.aboutBox.AddTranslator("https://translations.launchpad.net/playonlinux/")
+    self.aboutBox.AddArtist(_("Icons are provided by the Tango Desktop Project"))
     self.aboutBox.SetWebSite("http://www.playonlinux.com")
     self.aboutBox.SetLicence(open(Variables.playonlinux_env+"/LICENCE",'r').read())
     self.about = wx.AboutBox(self.aboutBox)
