@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (C) 2007 Pâris Quentin
+# Copyright (C) 2007-2010 PlayOnLinux Team
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,6 +28,36 @@ lib.lng.Lang()
 timeout = 2
 socket.setdefaulttimeout(timeout)
 
+def keynat(string):
+    r'''A natural sort helper function for sort() and sorted()
+    without using regular expressions or exceptions.
+
+    >>> items = ('Z', 'a', '10th', '1st', '9')
+    >>> sorted(items)
+    ['10th', '1st', '9', 'Z', 'a']
+    >>> sorted(items, key=keynat)
+    ['1st', '9', '10th', 'a', 'Z']    
+
+    Borrowed from http://code.activestate.com/recipes/285264/#c6
+    by paul clinch.  
+
+    License is the PSF Python License, http://www.python.org/psf/license/ (GPL compatible)
+    '''
+    it = type(1)
+    r = []
+    for c in string:
+        if c.isdigit():
+            d = int(c)
+            if r and type( r[-1] ) == it: 
+                r[-1] = r[-1] * 10 + d
+            else: 
+                r.append(d)
+        else:
+            r.append(c.lower())
+    return r
+
+
+
 class getVersions(threading.Thread):
   def __init__(self):
 	threading.Thread.__init__(self)
@@ -96,8 +127,8 @@ class Onglets(wx.Notebook):
 	    self.list_ver_installed = wx.TreeCtrl(self.panelFenp, 107, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|wx.RAISED_BORDER, size=(562, 212), pos=(10,281))
 	    self.list_ver_installed.SetImageList(self.imagesapps_i)
 	    self.list_ver_installed.SetSpacing(0);
-	    wx.StaticText(self.panelFenp, -1, _("Installed Wine Versions :"),(10,261))
-	    wx.StaticText(self.panelFenp, -1, _("Available Wine Versions :"),(10,10))
+	    wx.StaticText(self.panelFenp, -1, _("Installed Wine versions: "),(10,261))
+	    wx.StaticText(self.panelFenp, -1, _("Available Wine versions: "),(10,10))
 	    # self.content =  wx.TextCtrl(self.panelFenp, 107, pos=(10,301), size=(562,212), style = wx.TE_MULTILINE | wx.TE_RICH2 | wx.CB_READONLY | wx.RAISED_BORDER)
 
 	    self.button_rm = wx.Button(self.panelFenp, wx.ID_REMOVE, pos=(388, 500), size=wx.DefaultSize)
@@ -133,7 +164,7 @@ class Onglets(wx.Notebook):
 	    self.list_game = wx.TreeCtrl(self.panelApps, 111, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|wx.RAISED_BORDER, size=(562, 400), pos=(10,30))
 	    self.list_game.SetImageList(self.images)
 	    self.list_game.SetSpacing(0);
-	    self.version = wx.StaticText(self.panelApps, -1, _("Version :"),(10,440))
+	    self.version = wx.StaticText(self.panelApps, -1, _("Version: "),(10,440))
 	   
 	    self.MenuVer = wx.ComboBox(self.panelApps, 112)
 	    self.VersionsLoad()
@@ -251,7 +282,7 @@ class MainWindow(wx.Frame):
 	root = self.onglets.list_game.AddRoot("")
 	self.i = 0
 	for game in self.games: 
-		self.file = Variables.playonlinux_rep+"configurations/installed/"+game.encode("utf-8")
+		self.file = Variables.playonlinux_rep+"configurations/installed/"+game
 		if(not os.path.isdir(self.file)):
 			fichier = open(self.file,"r").read()
 
@@ -287,7 +318,7 @@ class MainWindow(wx.Frame):
 		
   def delete(self, event):
 	version = self.onglets.list_ver_installed.GetItemText(self.onglets.list_ver_installed.GetSelection()).encode('utf-8')
-	if(wx.YES == wx.MessageBox("Are you sure you want to delete wine "+version+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
+	if(wx.YES == wx.MessageBox(_("Are you sure you want to delete Wine: ")+version+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
 			shutil.rmtree(Variables.playonlinux_rep+"/WineVersions/"+version)
 
 	self.onglets.VersionsLoad()
@@ -316,7 +347,7 @@ class MainWindow(wx.Frame):
 
 	root2 = self.onglets.list_ver_installed.AddRoot("")
 	installed_versions = os.listdir(Variables.playonlinux_rep+"/WineVersions/")
-	installed_versions.sort()
+	installed_versions.sort(key=keynat)
 	installed_versions.reverse()
 	self.i = 0
 	self.j = 0
